@@ -152,16 +152,10 @@ class Element(Base):
         self.stacked = False
 
     def __repr__(self):
-        class_name = self.__class__.__name__
-        nodeid = self.id
-        xy = str(self.xy)
-        width = self.colwidth
-        height = self.colheight
-        addr = id(self)
-
-        format = "<%(class_name)s '%(nodeid)s' %(xy)s " + \
-                 "%(width)dx%(height)d at 0x%(addr)08x>"
-        return format % locals()
+        format = "<%s '%s' %s %dx%d at 0x%08x>"
+        params = (self.__class__.__name__, self.id, str(self.xy),
+                  self.colwidth, self.colheight, id(self))
+        return format % params
 
     def set_color(self, color):
         self.color = images.color_to_rgb(color)
@@ -458,16 +452,10 @@ class DiagramEdge(Base):
         self.thick = None
 
     def __repr__(self):
-        class_name = self.__class__.__name__
-        node1_id = self.node1.id
-        node1_xy = self.node1.xy
-        node2_id = self.node2.id
-        node2_xy = self.node2.xy
-        addr = id(self)
-
-        format = "<%(class_name)s '%(node1_id)s' %(node1_xy)s - " + \
-                 "'%(node2_id)s' %(node2_xy)s, at 0x%(addr)08x>"
-        return format % locals()
+        format = "<%s '%s' %s - '%s' %s at 0x%08x>"
+        params = (self.__class__.__name__, self.node1.id, self.node1.xy,
+                  self.node2.id, self.node2.xy, id(self))
+        return format % params
 
     def set_dir(self, value):
         value = value.lower()
@@ -566,6 +554,7 @@ class Diagram(NodeGroup):
     _NodeGroup = NodeGroup
 
     classes = {}
+    shadow_style = 'blur'
     linecolor = (0, 0, 0)
     int_attrs = NodeGroup.int_attrs + \
                 ['node_width', 'node_height', 'span_width', 'span_height']
@@ -573,6 +562,7 @@ class Diagram(NodeGroup):
     @classmethod
     def clear(cls):
         super(NodeGroup, cls).clear()
+        cls.shadow_style = 'blur'
         cls.linecolor = (0, 0, 0)
         cls.classes = {}
 
@@ -588,7 +578,7 @@ class Diagram(NodeGroup):
 
     def set_plugin(self, name, attrs):
         try:
-            kwargs = dict([str(unquote(attr.name)), unquote(attr.value)] \
+            kwargs = dict([str(unquote(attr.name)), unquote(attr.value)]
                           for attr in attrs)
             plugins.load([name], diagram=self, **kwargs)
         except:
@@ -650,6 +640,14 @@ class Diagram(NodeGroup):
         self._NodeGroup.set_default_fontsize(fontsize)
         self._DiagramEdge.set_default_fontsize(fontsize)
 
+    def set_shadow_style(self, value):
+        value = value.lower()
+        if value in ('solid', 'blur', 'none'):
+            self.shadow_style = value
+        else:
+            msg = "WARNING: unknown shadow style: %s\n" % value
+            raise AttributeError(msg)
+
     def set_edge_layout(self, value):
         value = value.lower()
         if value in ('normal', 'flowchart'):
