@@ -57,6 +57,23 @@ class TestBootParams(unittest2.TestCase):
         sys.argv = ['', '-Tpdf', '--separate', 'input.diag']
         self.parser.parse()
 
+    @argv_wrapper
+    def test_svg_ignore_pil_option(self):
+        sys.argv = ['', '-Tsvg', '--ignore-pil', 'input.diag']
+        self.parser.parse()
+
+    @assertRaises(RuntimeError)
+    @argv_wrapper
+    def test_png_ignore_pil_option(self):
+        sys.argv = ['', '-Tpng', '--ignore-pil', 'input.diag']
+        self.parser.parse()
+
+    @assertRaises(RuntimeError)
+    @argv_wrapper
+    def test_pdf_ignore_pil_option(self):
+        sys.argv = ['', '-Tpdf', '--ignore-pil', 'input.diag']
+        self.parser.parse()
+
     @argv_wrapper
     def test_svg_nodoctype_option(self):
         sys.argv = ['', '-Tsvg', '--nodoctype', 'input.diag']
@@ -144,6 +161,19 @@ class TestBootParams(unittest2.TestCase):
         finally:
             os.unlink(tmp[1])
 
+    @argv_wrapper
+    def test_exist_font_config_option(self):
+        try:
+            tmp = tempfile.mkstemp()
+
+            sys.argv = ['', '-f', tmp[1], 'input.diag']
+            options = self.parser.parse()
+            self.assertEqual(options.font, [tmp[1]])
+            fontpath = detectfont(options)
+            self.assertEqual(fontpath, tmp[1])
+        finally:
+            os.unlink(tmp[1])
+
     @assertRaises(RuntimeError)
     @argv_wrapper
     def test_not_exist_font_config_option(self):
