@@ -23,7 +23,7 @@ from blockdiag.utils.fontmap import parse_fontpath, FontMap
 
 class Application(object):
     module = None
-    option = None
+    options = None
 
     def run(self):
         try:
@@ -40,7 +40,7 @@ class Application(object):
             sys.stderr.write(msg)
             return -1
         except Exception, e:
-            if self.option and self.options.debug:
+            if self.options and self.options.debug:
                 import traceback
                 traceback.print_exc()
             else:
@@ -71,6 +71,7 @@ class Application(object):
         drawer = DiagramDraw(self.options.type, diagram,
                              self.options.output, fontmap=self.fontmap,
                              code=self.code, antialias=self.options.antialias,
+                             ignore_pil=self.options.ignore_pil,
                              nodoctype=self.options.nodoctype,
                              transparency=self.options.transparency)
         drawer.draw()
@@ -111,6 +112,9 @@ class Options(object):
                      help='use FONT to draw diagram', metavar='FONT')
         p.add_option('--fontmap',
                      help='use FONTMAP file to draw diagram', metavar='FONT')
+        p.add_option('--ignore-pil', dest='ignore_pil',
+                     default=False, action='store_true',
+                     help='do not use PIL module forcely (SVG only)')
         p.add_option('--no-transparency', dest='transparency',
                      default=True, action='store_false',
                      help='do not make transparent background of diagram ' +
@@ -160,6 +164,10 @@ class Options(object):
                 msg = "could not output PDF format; Install reportlab."
                 raise RuntimeError(msg)
 
+        if self.options.ignore_pil and self.options.type != 'SVG':
+            msg = "--ignore-pil option work in SVG images."
+            raise RuntimeError(msg)
+
         if self.options.nodoctype and self.options.type != 'SVG':
             msg = "--nodoctype option work in SVG images."
             raise RuntimeError(msg)
@@ -238,13 +246,14 @@ def detectfont(options):
             msg = 'fontfile is not found: %s' % options.font
             raise RuntimeError(msg)
 
-    globber = (glob.glob(d) for d in fontdirs)
-    for fontdir in sum(globber, []):
-        for root, dirs, files in os.walk(fontdir):
-            for font in fontfiles:
-                if font in files:
-                    fontpath = os.path.join(root, font)
-                    break
+    if fontpath is None:
+        globber = (glob.glob(d) for d in fontdirs)
+        for fontdir in sum(globber, []):
+            for root, dirs, files in os.walk(fontdir):
+                for font in fontfiles:
+                    if font in files:
+                        fontpath = os.path.join(root, font)
+                        break
 
     return fontpath
 
